==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/gl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Vostede comentou",
    "%1$s commented" : "%1$s comentados",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Vostede comentou en %1$s",
    "You commented on {file}" : "Vostede comentou en {file}",
    "%1$s commented on %2$s" : "%1$s comentados en %2$s",
    "{author} commented on {file}" : "{author} comentou en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> para ficheiros",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Mencionárono en «{file}», nun comentario dun usuario que foi eliminado",
    "{user} mentioned you in a comment on “{file}”" : "{user} mencionouno a vostede nun comentario en «{file}»",
    "Files app plugin to add comments to files" : "Engadido da aplicación de ficheiros para engadir comentarios aos ficheiros",
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Eliminar comentario",
    "New comment …" : "Comentario novo…",
    "Post" : "Publicar",
    "Cancel" : "Cancelar",
    "[Deleted user]" : "[Usuario eliminado]",
    "No comments yet, start the conversation!" : "Aínda non hai comentarios, comeza a conversa!",
    "More comments …" : "Máis comentarios…",
    "Save" : "Gardar",
    "Allowed characters {count} of {max}" : "Caracteres permitidos {count} de {max}",
    "Error occurred while retrieving comment with ID {id}" : "Produciuse un erro ao recuperar o comentario co ID {id}",
    "Error occurred while updating comment with id {id}" : "Produciuse un erro ao actualizar o comentario co ID {id}",
    "Error occurred while posting comment" : "Produciuse un erro ao publicar o comentario",
    "_%n unread comment_::_%n unread comments_" : ["%n comentario sen ler","%n comentarios sen ler"],
    "_1 new comment_::_{unread} new comments_" : ["1 comentario novo","{unread} comentarios novos"],
    "Comment" : "Comentario"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/gl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Vostede comentou",
    "%1$s commented" : "%1$s comentados",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Vostede comentou en %1$s",
    "You commented on {file}" : "Vostede comentou en {file}",
    "%1$s commented on %2$s" : "%1$s comentados en %2$s",
    "{author} commented on {file}" : "{author} comentou en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> para ficheiros",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Mencionárono en «{file}», nun comentario dun usuario que foi eliminado",
    "{user} mentioned you in a comment on “{file}”" : "{user} mencionouno a vostede nun comentario en «{file}»",
    "Files app plugin to add comments to files" : "Engadido da aplicación de ficheiros para engadir comentarios aos ficheiros",
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Eliminar comentario",
    "Cancel edit" : "Cancelar a edición",
    "Post comment" : "Publicar comentario",
    "No comments yet, start the conversation!" : "Aínda non hai comentarios, comeza a conversa!",
    "No more messages" : "Non hai máis mensaxes",
    "Retry" : "Volver tentar",
    "Unable to load the comments list" : "Non é posíbel cargar a lista de comentarios",
    "_%n unread comment_::_%n unread comments_" : ["%n comentario sen ler","%n comentarios sen ler"],
    "_1 new comment_::_{unread} new comments_" : ["1 comentario novo","{unread} comentarios novos"],
    "Comment" : "Comentario",
    "An error occurred while trying to edit the comment" : "Produciuse un erro mentres tentaba editar o comentario",
    "Comment deleted" : "Comentario eliminado",
    "An error occurred while trying to delete the comment" : "Produciuse un erro mentres tentaba eliminar o comentario",
    "An error occurred while trying to create the comment" : "Produciuse un erro mentres tentaba crear o comentario",
    "New comment …" : "Comentario novo…",
    "Post" : "Publicar",
    "Cancel" : "Cancelar",
    "[Deleted user]" : "[Usuario eliminado]",
    "More comments …" : "Máis comentarios…",
    "Save" : "Gardar",
    "Allowed characters {count} of {max}" : "Caracteres permitidos {count} de {max}",
    "Error occurred while retrieving comment with ID {id}" : "Produciuse un erro ao recuperar o comentario co ID {id}",
    "Error occurred while updating comment with id {id}" : "Produciuse un erro ao actualizar o comentario co ID {id}",
    "Error occurred while posting comment" : "Produciuse un erro ao publicar o comentario"
},
"nplurals=2; plural=(n != 1);");
